@@ -42,7 +42,7 @@ from typing import Generic, Iterator, TypeVar
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import RuntimeType
+from .literals import ArchitectureType, RuntimeType
 from .type_defs import (
     ListAliasesResponseTypeDef,
     ListCodeSigningConfigsResponseTypeDef,
@@ -57,7 +57,7 @@ from .type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -89,7 +89,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListAliasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListAliases)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListAliases)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listaliasespaginator)
     """
 
@@ -97,101 +97,101 @@ class ListAliasesPaginator(Boto3Paginator):
         self,
         *,
         FunctionName: str,
-        FunctionVersion: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        FunctionVersion: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAliasesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListAliases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListAliases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listaliasespaginator)
         """
 
 
 class ListCodeSigningConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listcodesigningconfigspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCodeSigningConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listcodesigningconfigspaginator)
         """
 
 
 class ListEventSourceMappingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listeventsourcemappingspaginator)
     """
 
     def paginate(
         self,
         *,
-        EventSourceArn: str = None,
-        FunctionName: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        EventSourceArn: str = ...,
+        FunctionName: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEventSourceMappingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listeventsourcemappingspaginator)
         """
 
 
 class ListFunctionEventInvokeConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctioneventinvokeconfigspaginator)
     """
 
     def paginate(
-        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListFunctionEventInvokeConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctioneventinvokeconfigspaginator)
         """
 
 
 class ListFunctionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionspaginator)
     """
 
     def paginate(
         self,
         *,
-        MasterRegion: str = None,
-        FunctionVersion: Literal["ALL"] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        MasterRegion: str = ...,
+        FunctionVersion: Literal["ALL"] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListFunctionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionspaginator)
         """
 
 
 class ListFunctionsByCodeSigningConfigPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionsbycodesigningconfigpaginator)
     """
 
     def paginate(
-        self, *, CodeSigningConfigArn: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, CodeSigningConfigArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListFunctionsByCodeSigningConfigResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionsbycodesigningconfigpaginator)
         """
 
 
 class ListLayerVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerversionspaginator)
     """
 
@@ -199,58 +199,60 @@ class ListLayerVersionsPaginator(Boto3Paginator):
         self,
         *,
         LayerName: str,
-        CompatibleRuntime: RuntimeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        CompatibleRuntime: RuntimeType = ...,
+        CompatibleArchitecture: ArchitectureType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListLayerVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerversionspaginator)
         """
 
 
 class ListLayersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListLayers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerspaginator)
     """
 
     def paginate(
         self,
         *,
-        CompatibleRuntime: RuntimeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        CompatibleRuntime: RuntimeType = ...,
+        CompatibleArchitecture: ArchitectureType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListLayersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListLayers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerspaginator)
         """
 
 
 class ListProvisionedConcurrencyConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listprovisionedconcurrencyconfigspaginator)
     """
 
     def paginate(
-        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListProvisionedConcurrencyConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listprovisionedconcurrencyconfigspaginator)
         """
 
 
 class ListVersionsByFunctionPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listversionsbyfunctionpaginator)
     """
 
     def paginate(
-        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListVersionsByFunctionResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listversionsbyfunctionpaginator)
         """
